.. _Optimus: https://github.com/sveetch/Optimus

This is the Readme file for the `Optimus`_ project : $PROJECT_NAME

Read the Optimus documentation on `<https://optimus.readthedocs.org/>`_.

Install
*******

::

    make install

Build
*****

For default environment (commonly for development) ::

    make build

For production environment ::

    make build-prod
